@@ -40,7 +40,7 @@ class Addon:
     """
     Indexer plugin wrapper
     """
-    def __init__(self, fname, **kw):
+    def __init__(self, fname, progress=None, **kw):
         self.filename = os.path.basename(fname)
         self.name = os.path.splitext(self.filename)[0]
         oldpath = sys.path
@@ -55,9 +55,14 @@ class Addon:
             self.obj = self.module.init()
         if self.obj:
             try:
-                self.info = self.obj.info(**kw)
-            except TypeError:
-                self.info = self.obj.info()
+                try:
+                    self.info = self.obj.info(**kw)
+                except TypeError:
+                    self.info = self.obj.info()
+            except Exception, e:
+                if progress:
+                    progress.warning("Plugin %s initialisation failed: %s" % (fname, str(e)))
+                self.obj = None
 
     def finished(self):
         if hasattr(self.obj, "finished"):
